# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['libretrofuzz']

package_data = \
{'': ['*']}

install_requires = \
['beautifulsoup4>=4.12.2,<5.0.0',
 'httpx>=0.28.1,<0.29.0',
 'prompt_toolkit>=3.0.36,<4.0.0',
 'questionary>=2.0.1,<3.0.0',
 'rapidfuzz>=3.9.7,<4.0.0',
 'regex>=2023.10.3,<2024.0.0',
 'tqdm>=4.66.1,<5.0.0',
 'typer[all]>=0.15.4,<0.16.0']

extras_require = \
{':platform_machine not in "aarch64" and platform_machine not in "armv8"': ['pillow>=10.1.0,<11.0.0']}

entry_points = \
{'console_scripts': ['libretro-fuzz = libretrofuzz.__main__:fuzzsingle',
                     'libretro-fuzzall = libretrofuzz.__main__:fuzzall']}

setup_kwargs = {
    'name': 'libretrofuzz',
    'version': '3.6.8',
    'description': 'Fuzzy Retroarch thumbnail downloader',
    'long_description': "**Fuzzy Retroarch thumbnail downloader**\n========================================\n\nIn Retroarch, when you use the manual scanner to get nonstandard games or hacks in playlists, thumbnails often fail to download.\n\nThese programs, for each game label on a playlist, download the most similar named image to display in retroarch.\n\nThere are several options to fit unusual labels and increase fuzziness, but you can just run them to get a adequate default that is neither too strict or lax.\n\nIf you still want more thumbnails, using ``libretro-fuzz --min 80 --delay 15 --delay-after 15`` works (smaller ``--min`` increases fuzz), with some delays introduced to check if you want to keep the game selected for the thumbnails. If you prefer only exact matches, use ``--min 100``.\n\nIf you use ``libretro-fuzz``, it will download for a single playlist by asking for the playlist and system if they're not provided.\nIf you use ``libretro-fuzzall``, it will download for all playlists with standard libretro names, and will skip custom playlists.\n\nBesides those differences, if no retroarch.cfg is provided, both programs try to use the default retroarch.cfg.\n\nIf `chafa <https://github.com/hpjansson/chafa>`_ is installed, the program will display new thumbnails of a game, with gray border for images already in use and with green border for new images. Chafa works better with a recent release and on a `sixel <https://en.wikipedia.org/wiki/Sixel>`_ or `kitty <https://sw.kovidgoyal.net/kitty/graphics-protocol/>`_ compatible shell.\n\nExample:\n | ``libretro-fuzz --system 'Commodore - Amiga' --before '_'``\n\n The Retroplay WHDLoad set has labels like ``MonkeyIsland2_v1.3_0020`` after a manual scan. These labels *often* don't have subtitles (but not always) and all the metadata is not separated from the name by brackets. Select the playlist that contains those whdloads to download from the libretro amiga thumbnails.\n\nNote that the system name you download from doesn't have to be the same as the playlist name.\n\nIf the thumbnail server contains games from multiple releases for the system (like ``ScummVM``), be careful using extra options since it is easy to end up with 'slightly wrong' covers.\n\nExample:\n ``libretro-fuzz --no-meta --no-merge``\n\n After downloading ``ScummVM`` thumbnails (and not before, to minimize false positives), we'd like to try to pickup a few covers from ``DOS`` thumbnails and skip download if there a risk of mixing thumbnails from ``DOS`` and ``ScummVM`` for a single game.\n Choose the ScummVM playlist and DOS system name, and covers would be downloaded with risk of false positives: CD vs floppy covers, USA vs Japan covers, or another platform vs DOS.\n\nBecause of this increased risk of false positives with options, the default is to count everything except hack metadata as part of the match and the default pre-selected system name to be the same as the playlist name, which is safest.\n\nA common scenario is the thumbnail server not having a single thumbnail of the game, and the program selecting the best match it can which is still good enough to pass, like a sequel, prequel, or different release, most often regions/languages. It's not recommended to use ``--min`` less than 90 without ``--filter`` to a specific game, or at least ``--delay/--delay-after`` to be able to cancel.\n\nExample:\n  ``libretro-fuzz --system 'Commodore - Amiga' --before '_' --filter '[Ii]shar*'``\n\n  The best way to solve these issues is to upload the right cover to the respective libretro-thumbnail subproject with the correct name of the game variant. Then you can redownload just the updated thumbnails with a label, in this example, because of ``--filter``, the Ishar series in the WHDLoad playlist would redownload because the glob used matches all names that start with 'Ishar' or 'ishar'.\n\nTo debug why a game is not being matched, SHORT=1 before the command will display the simplified names checked for similarity.\n\nlibretro-fuzzall/libretro-fuzz [OPTIONS] [CFG]\n  :CFG:                 Path to the retroarch cfg file. If not default, asked from the user.\n\n                        Linux default:   ``~/.config/retroarch/retroarch.cfg``\n\n                        Windows default: ``%APPDATA%/RetroArch/retroarch.cfg``\n\n                        MacOS default:   ``~/Library/Application Support/RetroArch/config/retroarch.cfg``\n\n                        Android default: ``/storage/emulated/0/Android/data/com.retroarch/files/retroarch.cfg``\n\n  --playlist <NAME libretro-fuzz only>\n                        | Playlist name with labels used for thumbnail fuzzy matching.\n                        | If not provided, asked from the user.\n  --system <NAME libretro-fuzz only>\n                        | Directory name in the server to download thumbnails.\n                        | If not provided, asked from the user.\n  --delay-after SECS    | Seconds after download to skip replacing thumbnails, enter continues.\n                        | No-op with ``--no-image``.\n                        | [1<=x<=60]\n  --delay SECS          | Seconds to skip thumbnails download, enter continues.\n                        | [1<=x<=60]\n  --filter GLOB         | Restricts downloads to game labels globs - not paths - in the playlist, can be used multiple times.\n                        | Resets thumbnails, ``--filter '*'`` redownloads all.\n  --min SCORE           | 0=any, 100≃equal, 90=default. No-op with ``--no-fail``.\n                        | [default: 90; 0<=x<=100]\n  --no-fail             Download any score. Equivalent to ``--min 0``.\n  --no-image            Don't show images even with chafa installed.\n  --no-merge            | Disables missing thumbnails download for a label if there is at least one in cache to avoid mixing thumbnails from different server directories on repeated calls.\n                        | No-op with ``--filter``.\n  --no-meta             | Ignores () delimited metadata.\n                        | May cause false positives.\n                        | Forced with ``--before``.\n  --hack                | Matches [] delimited metadata, best used if the hack has thumbnails.\n                        | May cause false positives.\n                        | Ignored with ``--before``.\n  --before TEXT         | Use only the part of the label before TEXT to match.\n                        | TEXT may not be inside of brackets of any kind.\n                        | May cause false positives.\n                        | Forces ignoring metadata.\n  --address URL         | URL with libretro-thumbnails server, for local files:\n                        | Go to RA thumbnail dir/git clone/unzip packs;\n                        | Run ``'python3 -m http.server'`` in parent dir;\n                        | Then use ``--address 'http://localhost:8000'``.\n                        | [default: https://thumbnails.libretro.com]\n  --dry-run             Print results only, no image download.\n  --limit GAMES         | Show a number of winners or losers.\n                        | Any equal score winners can download images.\n                        | [default: 1; x>=1]\n  --verbose             Show failed matches.\n  --install-completion  Install completion for the current shell.\n  --show-completion     Show completion for the current shell, to copy it or customize the installation.\n  --help                Show this message and exit.\n\n\n\nTo install the program, type on the cmd line\n\n+----------------+---------------------------------------------------------------------------------------------+\n| Latest release | ``pip install --force-reinstall libretrofuzz``                                              |\n+----------------+---------------------------------------------------------------------------------------------+\n| Current code   | ``pip install --force-reinstall https://github.com/i30817/libretrofuzz/archive/master.zip`` |\n+----------------+---------------------------------------------------------------------------------------------+\n\nIn windows, you'll want to check the option to “Add Python to PATH” when installing python, to be able to install and execute the script from any path of the cmd line.\n\nIn android, first install termux from `F-Droid <https://f-droid.org/packages/com.termux/>`_ (play store version is out of date and can't be updated), then run in termux ``pkg install python3 termux-tools ; termux-setup-storage``.\n\nThe first command installs python3 (and pip3) and some termux scripts, the second command will make a symlink to the shared storage of android so it's easier to pass a retroarch.cfg file, or navigate to a directory to use the local http.server ``--address`` trick (to run the server and program at the same time, in termux you can open multiple sessions of the shell by touch and hold near the top left edge).\n",
    'author': 'i30817',
    'author_email': 'i30817@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/i30817/libretrofuzz',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
